#
# spec file for package python-Mako
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-Mako
Version:        1.0.1
Release:        7.7
Url:            http://www.makotemplates.org/
Summary:        A super-fast Python templating language
License:        MIT
Group:          Development/Languages/Python
Source:         http://pypi.python.org/packages/source/M/Mako/Mako-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python-MarkupSafe
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
BuildRequires:  python-argparse
%endif
BuildRequires:  python-devel
BuildRequires:  python-mock
BuildRequires:  python-nose
BuildRequires:  python-setuptools
%if 0%{?suse_version}
Suggests:       python-Beaker >= 1.1
%endif
Requires:       python-MarkupSafe
Provides:       python-mako = %{version}
Obsoletes:      python-mako < %{version}
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
Mako is a template library written in Python. It provides a familiar, non-XML 
syntax which compiles into Python modules for maximum performance. Mako's 
syntax and API borrows from the best ideas of many others, including Django
templates, Cheetah, Myghty, and Genshi. Conceptually, Mako is an embedded 
Python (i.e. Python Server Page) language, which refines the familiar ideas
of componentized layout and inheritance to produce one of the most 
straightforward and flexible models available, while also maintaining close 
ties to Python calling and scoping semantics.

%prep
%setup -q -n Mako-%{version}

%build
python setup.py build

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

%if 0%{?suse_version} > 1320
#FIXME : the tests fail for openSUSE < to Factory
%check
python setup.py test
%endif

%files
%defattr(-,root,root,-)
%doc CHANGES LICENSE README.rst examples
%{_bindir}/mako-render
%{python_sitelib}/mako/
%{python_sitelib}/Mako-%{version}-py%{py_ver}.egg-info

%changelog
* Fri Jul 24 2015 seife+obs@b1-systems.com
- fix non-SUSE distro build by conditionalizing Suggests: tag
* Fri Mar 13 2015 p.drouand@gmail.com
- update to version 1.0.1:
  * [feature] Added support for Lingua, a translation extraction
    system as an alternative to Babel. Pull request courtesy Wichert
    Akkerman.
  * [bug] [py3k] Modernized the examples/wsgi/run_wsgi.py file for
    Py3k. Pull requset courtesy Cody Taylor.
- Disable temporary tests for non-Factory systems because of failures
* Tue Jul 29 2014 dmueller@suse.com
- fix up build for SLE11
* Fri Jul 18 2014 toddrme2178@gmail.com
- Update to version 1.0.0
  + Too many changes; please look at changelog in package documentation
* Thu Mar  6 2014 speilicke@suse.com
- Only suggest Beaker, it's an extra requirement and not really needed
* Mon Jan 13 2014 dmueller@suse.com
- update to 0.9.1:
  - [bug] Fixed bug in Babel plugin where translator comments
    would be lost if intervening text nodes were encountered.
    Fix courtesy Ned Batchelder.  [ticket:225]
  - [bug] Fixed TGPlugin.render method to support unicode template
    names in Py2K - courtesy Vladimir Magamedov.
  - [bug] Fixed an AST issue that was preventing correct operation
    under alpha versions of Python 3.4.  Pullreq courtesy Zer0-.
  - [bug] Changed the format of the "source encoding" header output
    by the code generator to use the format ``# -*- coding:%%s -*-``
    instead of ``# -*- encoding:%%s -*-``; the former is more common
    and compatible with emacs.  Courtesy Martin Geisler.
  - [bug] Fixed issue where an old lexer rule prevented a template line
    which looked like "#*" from being correctly parsed.  [ticket:224]
* Tue Sep  3 2013 dmueller@suse.com
- update to 0.9.0:
  - [bug] The Context.locals_() method becomes a private underscored
    method, as this method has a specific internal use. The purpose
    of Context.kwargs has been clarified, in that it only delivers
    top level keyword arguments originally passed to template.render().
    [ticket:219]
  - [bug] Fixed the babel plugin to properly interpret ${} sections
    inside of a "call" tag, i.e. <%%self:some_tag attr="${_('foo')}"/>.
    Code that's subject to babel escapes in here needs to be
    specified as a Python expression, not a literal.  This change
    is backwards incompatible vs. code that is relying upon a _('')
    translation to be working within a call tag.
  - [bug] The Babel plugin has been repaired to work on Python 3.
    [ticket:187]
  - [bug] Using <%%namespace import="*" module="somemodule"/> now
    skips over module elements that are not explcitly callable,
    avoiding TypeError when trying to produce partials.
    [ticket:207]
  - [bug] Fixed Py3K bug where a "lambda" expression was not
    interpreted correctly within a template tag; also
    fixed in Py2.4.  [ticket:190]
* Tue Jun 25 2013 dmueller@suse.com
- update to 0.8.1:
  - [bug] Changed setup.py to skip installing markupsafe
  if Python version is < 2.6 or is between 3.0 and
  less than 3.3, as Markupsafe now only supports 2.6->2.X,
  3.3->3.X. [ticket:216]
  - [bug] Fixed regression where "entity" filter wasn't
  converted for py3k properly (added tests.)
  [ticket:214]
  - [bug] Fixed bug where mako-render script wasn't
  compatible with Py3k.  [ticket:212]
  - [bug] Cleaned up all the various deprecation/
  file warnings when running the tests under
  various Pythons with warnings turned on.
  [ticket:213]
  - [feature] Performance improvement to the
  "legacy" HTML escape feature, used for XML
  escaping and when markupsafe isn't present,
  courtesy George Xie.
  - [bug] Fixed bug whereby an exception in Python 3
  against a module compiled to the filesystem would
  fail trying to produce a RichTraceback due to the
  content being in bytes. [ticket:209]
  - [bug] Change default for compile()->reserved_names
  from tuple to frozenset, as this is expected to be
  a set by default.  [ticket:208]
  - [feature] Code has been reworked to support Python 2.4->
  Python 3.xx in place.  2to3 no longer needed.
  - [feature] Added lexer_cls argument to Template,
  TemplateLookup, allows alternate Lexer classes
  to be used.
  - [feature] Added future_imports parameter to Template
  and TemplateLookup, renders the __future__ header
  with desired capabilities at the top of the generated
  template module.  Courtesy Ben Trofatter.
* Thu Nov 22 2012 saschpe@suse.de
- Update to version 0.7.3:
  + [bug] legacy_html_escape function, used when
    Markupsafe isn't installed, was using an inline-compiled
    regexp which causes major slowdowns on Python 3.3;
    is now precompiled.
  + [bug] AST supporting now supports tuple-packed
    function arguments inside pure-python def
    or lambda expressions.
  + [bug] Fixed Py3K bug in the Babel extension.
  + [bug] Fixed the "filter" attribute of the
    <%%text> tag so that it pulls locally specified
    identifiers from the context the same
    way as that of <%%block> and <%%filter>.
  + [bug] Fixed bug in plugin loader to correctly
    raise exception when non-existent plugin
    is specified.
- Changes from version 0.7.2:
  + [bug] Fixed regression in 0.7.1 where AST
    parsing for Py2.4 was broken.
- Changes from version 0.7.1:
  + [feature] Control lines with no bodies will
    now succeed, as "pass" is added for these
    when no statements are otherwise present.
  + [bug] Fixed some long-broken scoping behavior
    involving variables declared in defs and such,
    which only became apparent when
    the strict_undefined flag was turned on.
  + [bug] Can now use strict_undefined at the
    same time args passed to def() are used
    by other elements of the <%%def> tag.
- Don't give the Python2 binary the prefix "python3"
* Fri May 25 2012 toddrme2178@gmail.com
- Fix building on openSUSE 11.4
- spec file cleanups
* Wed May 23 2012 highwaystar.ru@gmail.com
- python3 package added
- Update to 0.7.0
  - Added new "loop" variable to templates, is provided within a %%
    for block to provide info about the loop such as index,
    first/last, odd/even, etc.  A migration path is also provided
    for legacy templates via the "enable_loop" argument available
    on Template, TemplateLookup, and <%%page>.
  - Added a real check for "reserved" names, that is names which
    are never pulled from the context and cannot be passed to the
    template.render() method.  Current names are "context", "loop",
    "UNDEFINED".
  - The html_error_template() will now apply Pygments highlighting
    to the source code displayed in the traceback, if Pygments if
    available.
  - Added support for context managers,
    i.e. "%% with x as e:/ %% endwith" support.
  - Added class-level flag to CacheImpl "pass_context"; when True,
    the keyword argument 'context' will be passed to
    get_or_create() containing the Mako Context object.
  - Added Jinja2 to the example benchmark suite
  - Bugfixes
- Update to 0.6.2
  - Bugfixes
- Update to 0.6.1
  - Bugfixes
- Update to 0.6.0
  - Template caching has been converted into a plugin system,
    whereby the usage of Beaker is just the default plugin.
    Template and TemplateLookup now accept a string "cache_impl"
    parameter which refers to the name of a cache plugin,
    defaulting to the name 'beaker'. New plugins can be registered
    as pkg_resources entrypoints under the group "mako.cache", or
    registered directly using mako.cache.register_plugin().  The
    core plugin is the mako.cache.CacheImpl class.
  - Added support for Beaker cache regions in templates. Usage of
    regions should be considered as superseding the very obsolete
    idea of passing in backend options, timeouts, etc. within
    templates.
  - The 'put' method on Cache is now 'set'. 'put' is there for
    backwards compatibility.
  - The <%%def>, <%%block> and <%%page> tags now accept any argument
    named "cache_*", and the key minus the "cache_" prefix will be
    passed as keyword arguments to the CacheImpl methods.
  - Template and TemplateLookup now accept an argument cache_args,
    which refers to a dictionary containing cache parameters. The
    cache_dir, cache_url, cache_type, cache_timeout arguments are
    deprecated (will probably never be removed, however) and can be
    passed now as cache_args={'url':<some url>, 'type':'memcached',
    'timeout':50, 'dir':'/path/to/some/directory'}
  - Can now refer to context variables within extra arguments to
    <%%block>, <%%def>,
    i.e. <%%block name="foo" cache_key="${somekey}">. Filters can
    also be used in this way,
    i.e. <%%def name="foo()" filter="myfilter"> then
    template.render(myfilter=some_callable)
  - Added "--var name=value" option to the mako-render script,
    allows passing of kw to the template from the command line.
  - Added module_writer argument to Template, TemplateLookup,
    allows a callable to be passed which takes over the writing of
    the template's module source file, so that special
    environment-specific steps can be taken.
  - Bugfixes
* Thu Nov 10 2011 saschpe@suse.de
- Update to version 0.5.0:
  * A Template is explicitly disallowed from having a url that
    normalizes to relative outside of the root. [ticket:174]
* Thu Sep  1 2011 saschpe@suse.de
- Added python-nose BuildRequires for testsuite and packages make-render
  binary
* Thu Sep  1 2011 saschpe@suse.de
- Update to version 0.4.2:
  * Fixed bug regarding <%%call>/def calls w/ content whereby the identity
    of the "caller" callable inside the <%%def> would be corrupted by the
    presence of another <%%call> in the same block. [ticket:170]
  * Fixed the babel plugin to accommodate <%%block> [ticket:169]
- Simpler spec file
* Thu Jul  1 2010 jfunk@funktronics.ca
- Update to 0.3.4
  - Now using MarkupSafe for HTML escaping,
    i.e. in place of cgi.escape().  Faster
    C-based implementation and also escapes
    single quotes for additional security.
    Supports the __html__ attribute for
    the given expression as well.
    When using "disable_unicode" mode,
    a pure Python HTML escaper function
    is used which also quotes single quotes.
    Note that Pylons by default doesn't
    use Mako's filter - check your
    environment.py file.
  - Fixed call to "unicode.strip" in
    exceptions.text_error_template which
    is not Py3k compatible.  [ticket:137]
* Tue Sep  8 2009 jfunk@funktronics.ca
- Update to 0.2.5
  - Added a "decorator" kw argument to <%%def>, allows custom decoration
    functions to wrap rendering callables.  Mainly intended for custom caching
    algorithms, not sure what other uses there may be (but there may be).
    Examples are in the "filtering" docs.
  - When Mako creates subdirectories in which to store templates, it uses the
    more permissive mode of 0775 instead of 0750, helping out with certain
    multi-process scenarios. Note that the mode is always subject to the
    restrictions of the existing umask. [ticket:101]
  - Fixed namespace.__getattr__() to raise AttributeError on attribute not
    found instead of RuntimeError.  [ticket:104]
  - Added last_modified accessor to Template, returns the time.time() when the
    module was created. [ticket:97]
  - Fixed lexing support for whitespace around '=' sign in defs. [ticket:102]
  - Removed errant "lower()" in the lexer which was causing tags to compile
    with case-insensitive names, thus messing up custom <%%call> names.
    [ticket:108]
  - added "mako.__version__" attribute to the base module.  [ticket:110]
* Thu Sep  3 2009 matejcik@suse.cz
- build as noarch
* Thu Sep  3 2009 matejcik@suse.cz
- importing package from OBS, original changelog follows
* Mon Aug 10 2009 Ciaran Farrell <cfarrell1980@gmail.com> - 0.2.4-1
- Update to 0.2.4
* Tue Dec  2 2008 James Oakley <jfunk@funktronics.ca> - 0.2.3-1
- Initial release
